package tech.mercantec.easyeat.ui.profile

import android.app.ProgressDialog
import android.content.Intent
import android.os.Bundle
import android.widget.Button
import android.widget.EditText
import android.widget.TextView
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.updateUser
import kotlin.concurrent.thread

class EditProfileActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_edit_profile)

        findViewById<EditText>(R.id.username).setText(intent.extras?.getString("username"), TextView.BufferType.EDITABLE)
        findViewById<EditText>(R.id.email).setText(intent.extras?.getString("email"), TextView.BufferType.EDITABLE)

        findViewById<Button>(R.id.save).setOnClickListener {
            val username = findViewById<EditText>(R.id.username).text.toString().trim()
            val email = findViewById<EditText>(R.id.email).text.toString().trim()

            val progressDialog = ProgressDialog(this)
            progressDialog.setMessage("Loading...")
            progressDialog.show()

            thread {
                try {
                    updateUser(this, username, email)
                } catch (e: ApiRequestException) {
                    runOnUiThread {
                        Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                    }

                    return@thread
                } finally {
                    runOnUiThread {
                        progressDialog.hide()
                    }
                }

                val intent = Intent()
                intent.putExtra("username", username)
                intent.putExtra("email", email)
                setResult(RESULT_OK, intent)

                finish()
            }
        }
    }
}
