package tech.mercantec.easyeat.ui.profile

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.core.view.children
import androidx.fragment.app.Fragment
import tech.mercantec.easyeat.ui.auth.WelcomeActivity
import tech.mercantec.easyeat.databinding.FragmentProfileBinding
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.UserInfoResponse
import tech.mercantec.easyeat.helpers.getUserInfo
import tech.mercantec.easyeat.helpers.logout
import kotlin.concurrent.thread

class ProfileFragment : Fragment() {
    private lateinit var launcher: ActivityResultLauncher<Intent>
    private lateinit var binding: FragmentProfileBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        launcher = registerForActivityResult(ActivityResultContracts.StartActivityForResult()) {
            if (it.data == null || it.resultCode != Activity.RESULT_OK) return@registerForActivityResult

            binding.username.text = it.data!!.getStringExtra("username")
            binding.email.text = it.data!!.getStringExtra("email")
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = FragmentProfileBinding.inflate(inflater, container, false)

        binding.layout.children.forEach { it.visibility = View.GONE }
        binding.loading.visibility = View.VISIBLE

        thread {
            val userInfo: UserInfoResponse
            try {
                userInfo = getUserInfo(requireContext())
            } catch (e: ApiRequestException) {
                activity?.runOnUiThread {
                    Toast.makeText(activity?.applicationContext, e.message, Toast.LENGTH_LONG).show()
                }

                return@thread
            } finally {
                activity?.runOnUiThread {
                    binding.layout.children.forEach { it.visibility = View.VISIBLE }
                    binding.loading.visibility = View.GONE
                }
            }

            activity?.runOnUiThread {
                binding.username.text = userInfo.userName
                binding.email.text = userInfo.email

                binding.editProfile.setOnClickListener {
                    val intent = Intent(activity, EditProfileActivity::class.java)
                    intent.putExtra("username", binding.username.text)
                    intent.putExtra("email", binding.email.text)

                    launcher.launch(intent)
                }
            }
        }

        binding.changePassword.setOnClickListener {
            startActivity(Intent(activity, ChangePasswordActivity::class.java))
        }

        binding.logout.setOnClickListener {
            logout(requireContext())

            val intent = Intent(activity, WelcomeActivity::class.java)
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_CLEAR_TASK
            startActivity(intent)
        }

        return binding.root
    }
}
