package tech.mercantec.easyeat.ui.shopping_list

import android.content.Context
import android.graphics.Paint
import android.icu.text.DecimalFormat
import android.util.TypedValue
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ArrayAdapter
import android.widget.ImageView
import android.widget.TextView
import androidx.core.content.ContextCompat
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.models.ShoppingListItem

class ShoppingItemAdapter(context: Context, items: ArrayList<ShoppingListItem>)
    : ArrayAdapter<ShoppingListItem>(context, R.layout.shopping_list_item, items) {

    override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
        val item = getItem(position)
        val view = convertView ?: LayoutInflater.from(context).inflate(R.layout.shopping_list_item, parent, false)

        item?.let { item ->
            val checkmarkView = view.findViewById<ImageView>(R.id.checkmark)
            val amountView = view.findViewById<TextView>(R.id.amount)
            val unitView = view.findViewById<TextView>(R.id.unit)
            val nameView = view.findViewById<TextView>(R.id.name)
            val textViews = listOf(amountView, unitView, nameView)

            amountView.text = DecimalFormat("#.##").format(item.amount)
            unitView.text = item.unit
            nameView.text = item.name

            if (item.checked) {
                textViews.forEach {
                    it.paintFlags = it.paintFlags or Paint.STRIKE_THRU_TEXT_FLAG

                    val color = TypedValue()
                    context.theme.resolveAttribute(R.attr.colorDisabled, color, true)
                    it.setTextColor(ContextCompat.getColor(context, color.resourceId))
                }

                checkmarkView.visibility = View.VISIBLE
            } else {
                textViews.forEach {
                    it.paintFlags = it.paintFlags and Paint.STRIKE_THRU_TEXT_FLAG.inv()

                    val color = TypedValue()
                    context.theme.resolveAttribute(android.R.attr.textColorSecondary, color, true)
                    it.setTextColor(ContextCompat.getColor(context, color.resourceId))
                }

                checkmarkView.visibility = View.INVISIBLE
            }
        }

        return view
    }
}
